==> download.php?FileName=terralib-5.0.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_wcs_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>WCSConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="14"/>
        <source>WCS Connector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="39"/>
        <source>WCS - Web Coverage Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="51"/>
        <source>Service Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="70"/>
        <source>Data Source Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="80"/>
        <source>Data Source Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="99"/>
        <source>A more detailed description about the data source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="115"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="137"/>
        <source>&amp;Test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="144"/>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="151"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wcs::WCSConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="69"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="76"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="83"/>
        <source>TerraLib Qt Components</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="70"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="77"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="84"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wcs::WCSConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="145"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="152"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="182"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="190"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="196"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="204"/>
        <source>TerraLib Qt Components</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="153"/>
        <source>Unknown error while opening WCS data source!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="183"/>
        <source>Data source is ok!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="197"/>
        <source>Unknown error while testing WCS data source!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="205"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.1.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_wcs_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>WCSConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="14"/>
        <source>WCS Connector</source>
        <translation>Conector WCS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="39"/>
        <source>WCS - Web Coverage Service</source>
        <translation>WCS - Web Coverage Service</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="51"/>
        <source>Service Address</source>
        <translation>Endereço do Serviço</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="70"/>
        <source>Data Source Title</source>
        <translation>Título da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="80"/>
        <source>Data Source Description</source>
        <translation>Descrição da Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="99"/>
        <source>A more detailed description about the data source</source>
        <translation>Uma descrição mais detalhada sobre a fonte de dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="115"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="137"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="144"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/ui/WCSConnectorDialogForm.ui" line="151"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wcs::WCSConnector</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="69"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="76"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="83"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="70"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="77"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnector.cpp" line="84"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::wcs::WCSConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="145"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="152"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="182"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="190"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="196"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="204"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="153"/>
        <source>Unknown error while opening WCS data source!</source>
        <translation>Erro desconhecido ao abrir fonte de dados WCS !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="183"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="197"/>
        <source>Unknown error while testing WCS data source!</source>
        <translation>Erro desconhecido enquanto testando fonte de dados WCS !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/wcs/WCSConnectorDialog.cpp" line="205"/>
        <source>Not implemented yet!
We will provide it soon!</source>
        <translation>Ainda não implementado!
Iremos fornecer em breve!</translation>
    </message>
</context>
</TS>
